@@ -1,11 +1,11 @@
 from django import forms
+from edc_crf.crf_form_validator import CrfFormValidator
 from edc_crf.modelform_mixins import CrfModelFormMixin
-from edc_form_validators.form_validator import FormValidator
 
 from ..models import Sf12
 
 
-class Sf12FormValidator(FormValidator):
+class Sf12FormValidator(CrfFormValidator):
     pass
 
 
